@@ -4,10 +4,13 @@ from volworld_aws_api_common.test.aws.request.post__login import act__login
 from volworld_aws_api_common.api.AA import AA
 from volworld_common.test.behave.BehaveUtil import BehaveUtil
 from volworld_aws_api_common.test.behave.ACotA import ACotA
+from volworld_aws_api_common.api.enum.ErrorCode import ErrorCode
+from typing import Final
 
+DEFAULT_USER_PASSWORD: Final[str] = 'default_password'
 
 class UserInfo:
-    def __init__(self, name: str, password: str = 'default_password', rand_user: bool = True):
+    def __init__(self, name: str, password: str = DEFAULT_USER_PASSWORD, rand_user: bool = True):
         self.name = name
         # for testing wrong formatted username, put the name before generated id
         subfix = ''
@@ -20,7 +23,7 @@ class UserInfo:
 
     def signup(self):
         login = act__signup(self.used_name, self.password)
-        if AA.___Error___ in login:
+        if login[AA.___Error___] is not None:
             if login[AA.___Error___][AA.Code] == ErrorCode.UserNameExisting:
                 print(f"{self.used_name} already exist!")
                 return
@@ -31,10 +34,11 @@ class UserInfo:
         if not forced and self.login_info is not None:
             return
 
-        # print("act__login")
+        print("act__login")
         self.login_info = act__login(self.used_name, self.password)
-        # print("set token")
+        print("login_info = ", self.login_info)
         self.token = self.login_info[AA.Token]
+        print("set token = ", self.token)
         # print("")
         # print("")
         return self.login_info
@@ -56,13 +60,13 @@ class UserPool:
         user.login()
         return user
 
-    def add_user(self, name: str, password: str = None, rand_user: bool = True) -> UserInfo:
+    def add_user(self, name: str, password: str = DEFAULT_USER_PASSWORD, rand_user: bool = True) -> UserInfo:
         name = BehaveUtil.clear_string(name)
         assert name not in self.users
         self.users[name] = UserInfo(name, password, rand_user=rand_user)
         return self.users[name]
 
-    def add_signup_user(self, name: str, password: str = None, rand_user: bool = True) -> UserInfo:
+    def add_signup_user(self, name: str, password: str = DEFAULT_USER_PASSWORD, rand_user: bool = True) -> UserInfo:
         name = BehaveUtil.clear_string(name)
         assert name not in self.users
         inf = UserInfo(name, password, rand_user=rand_user)
