@@ -15,7 +15,7 @@ def post__login(
         # status_code: int = -1
 ):
     resp_json, resp = post_request(
-        authUrl.doLoginUrl, {
+        authUrl.do_login_url(), {
             AA.Name: name,
             AA.Password: pw,
         }, req, AAList
