@@ -14,7 +14,7 @@ def post__signup(
         req: ATestRequest,
         ):
     resp_json, resp = post_request(
-        authUrl.doSignupUrl, {
+        authUrl.do_signup_url(), {
             AA.Name: name,
             AA.Password: pw,
         }, req, AAList
